@@ -13,9 +13,9 @@ from yams import ValidationError
 from logilab.mtconverter import xml_escape
 
 from cubicweb import _
-from cubicweb.view import StartupView
+from cubicweb_web.view import StartupView
 from cubicweb.crypto import decrypt
-from cubicweb.web import (
+from cubicweb_web import (
     Redirect,
     controller,
     form,
@@ -23,7 +23,7 @@ from cubicweb.web import (
     formwidgets as wdg,
     formfields as ff,
 )
-from cubicweb.web.views import forms, urlrewrite, basetemplates
+from cubicweb_web.views import forms, urlrewrite, basetemplates
 
 
 # Login form
